==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/DatePickerDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
import { CalendarDescriptionModule } from "./CalendarDescriptionModule";
import { ButtonDescriptionModule } from "./ButtonDescriptionModule";
import { IconDescriptionModule } from "./IconDescriptionModule";
import { InputGroupDescriptionModule } from "./InputGroupDescriptionModule";
import { DatePickerDescriptionMetadata } from "./DatePickerDescriptionMetadata";
/**
 * @hidden
 */
var DatePickerDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DatePickerDescriptionModule, _super);
    function DatePickerDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DatePickerDescriptionModule.register = function (a) {
        CalendarDescriptionModule.register(a);
        ButtonDescriptionModule.register(a);
        IconDescriptionModule.register(a);
        InputGroupDescriptionModule.register(a);
        DatePickerDescriptionMetadata.d(a);
    };
    DatePickerDescriptionModule.$t = markType(DatePickerDescriptionModule, 'DatePickerDescriptionModule');
    return DatePickerDescriptionModule;
}(Base));
export { DatePickerDescriptionModule };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/DatePickerDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "./type";
import { CalendarDescriptionModule } from "./CalendarDescriptionModule";
import { ButtonDescriptionModule } from "./ButtonDescriptionModule";
import { IconDescriptionModule } from "./IconDescriptionModule";
import { InputGroupDescriptionModule } from "./InputGroupDescriptionModule";
import { DatePickerDescriptionMetadata } from "./DatePickerDescriptionMetadata";
/**
 * @hidden
 */
var DatePickerDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DatePickerDescriptionModule, _super);
    function DatePickerDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DatePickerDescriptionModule.register = function (a) {
        CalendarDescriptionModule.register(a);
        ButtonDescriptionModule.register(a);
        IconDescriptionModule.register(a);
        InputGroupDescriptionModule.register(a);
        DatePickerDescriptionMetadata.d(a);
    };
    DatePickerDescriptionModule.$t = markType(DatePickerDescriptionModule, 'DatePickerDescriptionModule');
    return DatePickerDescriptionModule;
}(Base));
export { DatePickerDescriptionModule };
